@@ -1,20 +1,20 @@
 from abc import ABC, abstractmethod
 from numbers import Number
-from typing import Collection, Generic, List, NamedTuple, Optional, Tuple, TypeVar, Union
+from typing import Collection, Generic, List, NamedTuple, Tuple, TypeVar, Union
 
 import numpy as np
 import pandas as pd
 
 from copulae.copula.estimator import EstimationMethod, fit_copula
-from copulae.copula.exceptions import InputDataError, NotFittedError
-from copulae.copula.summary import FitSummary, SummaryType
+from copulae.copula.exceptions import InputDataError
+from copulae.copula.summary import SummaryType
 from copulae.core import pseudo_obs
 from copulae.types import Array, Numeric, Ties
 
 try:
-    from typing import Protocol
+    from typing import Literal, Protocol
 except ImportError:
-    from typing_extensions import Protocol
+    from typing_extensions import Literal, Protocol
 
 __all__ = ["BaseCopula", "CopulaCorrProtocol", "Param", "EstimationMethod", "TailDep"]
 
@@ -27,12 +27,11 @@ class BaseCopula(ABC, Generic[Param]):
     such as the :py:meth:`BaseCopula.fit` method.
     """
 
-    def __init__(self, dim: int, name: str):
+    def __init__(self, dim: int, name: str, fit_smry: SummaryType = None, columns: List[str] = None):
         self._dim = dim
         self._name = name
-
-        self._columns: Optional[List[str]] = None
-        self._fit_smry: Optional[FitSummary] = None
+        self._columns = columns
+        self._fit_smry = fit_smry
         self._bounds: Tuple[Number, Number] = (0, 0)
 
         assert isinstance(self.dim, int) and self.dim >= 2, 'Copula must have more than 2 dimensions'
@@ -129,24 +128,13 @@ class BaseCopula(ABC, Generic[Param]):
             raise InputDataError('Dimension of data does not match copula')
 
         x0 = np.asarray(x0) if x0 is not None and not isinstance(x0, np.ndarray) and isinstance(x0, Collection) else x0
-        fit_copula(self, data, x0, method, verbose, optim_options, kwargs.get('scale', 1))
+        self._fit_smry = fit_copula(self, data, x0, method, verbose, optim_options, kwargs.get('scale', 1))
 
         if isinstance(data, pd.DataFrame):
             self._columns = list(data.columns)
 
         return self
 
-    @property
-    def fit_smry(self):
-        if self._fit_smry is None:
-            raise NotFittedError
-        return self._fit_smry
-
-    @fit_smry.setter
-    def fit_smry(self, summary: FitSummary):
-        assert isinstance(summary, FitSummary) or summary is None, "Setting invalid object as fit summary"
-        self._fit_smry = summary
-
     def log_lik(self, data: np.ndarray, *, to_pobs=True, ties: Ties = 'average') -> float:
         r"""
          Returns the log likelihood (LL) of the copula given the data.
@@ -256,7 +244,7 @@ class BaseCopula(ABC, Generic[Param]):
         """
         raise NotImplementedError
 
-    def summary(self) -> SummaryType:
+    def summary(self, category: Literal['copula', 'fit'] = 'copula') -> SummaryType:
         """Constructs the summary information about the copula"""
         raise NotImplementedError
 
